Module cli

Module cli 

Command line interface.

Structs

Cli
DictName
Newtype string wrapper to overwrite Default with wty.
GlossaryArgs
GlossaryExtendedArgs
GlossaryExtendedLangs
Langs-like struct that validates edition for edition.
GlossaryLangs
Langs-like struct that validates edition for source and skips edition.
IpaArgs
IpaMergedArgs
IpaMergedLangs
Langs-like struct that only takes one language.
IsoArgs
LangSpecs
Unified language configuration. See crate::dict::Langs.
MainArgs
MainLangs
Langs-like struct that validates edition for target and skips edition.
Options
ReleaseArgs

Enums

Command
FilterKey
A key used to filter a WordEntry by one of its fields.