Module lang

Module lang 

Abstractions over language codes.

This file was generated and should not be edited directly. The source code can be found at scripts/build.py

Enums

Edition
EditionSpec
Lang

Traits

Code
Helper trait to ensure that some other traits are implemented.